import { getMergedStops, getMetro, getTram, parseOptions } from "$lib";
import type { MapData } from "$lib/types";
import type { RequestHandler } from "./$types";

export const GET: RequestHandler = async ({ fetch, url }) => {
	const options = parseOptions(url);
	const mapData: MapData = { lines: [], stops: [] };

	if (options.mode !== "extreme demon ultra miguel") {
		const lineColors: [GeoJSON.Feature, string][] = [];

		if (options.metro) lineColors.push(...(await getMetro(fetch)));
		if (options.tram) lineColors.push(...(await getTram(fetch)));

		mapData.lines = lineColors;

		if (options.mode === "easy") {
			const lineCodes = new Set<string>(lineColors.map(([f]) => f.properties!.code_ligne));
			const crossingStops = await getMergedStops(fetch, lineCodes);

			const strippedStops: [number, number][] = crossingStops.map((f) => {
				const coords = (f.geometry as GeoJSON.Point).coordinates;
				return [coords[1], coords[0]];
			});

			mapData.stops = strippedStops;
		}
	}

	return Response.json(mapData);
};
